<?php

namespace Litecms\TicketSystem\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\TicketSystem\Models\TicketSystem;

class TicketSystemPolicy
{

    /**
     * Determine if the given user can view the ticket_system.
     *
     * @param UserPolicy $user
     * @param TicketSystem $ticket_system
     *
     * @return bool
     */
    public function view(UserPolicy $user, TicketSystem $ticket_system)
    {
        if ($user->canDo('ticket_system.ticket_system.view') && $user->isAdmin()) {
            return true;
        }

        return $ticket_system->user_id == user_id() && $ticket_system->user_type == user_type();
    }

    /**
     * Determine if the given user can create a ticket_system.
     *
     * @param UserPolicy $user
     * @param TicketSystem $ticket_system
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ticket_system.ticket_system.create');
    }

    /**
     * Determine if the given user can update the given ticket_system.
     *
     * @param UserPolicy $user
     * @param TicketSystem $ticket_system
     *
     * @return bool
     */
    public function update(UserPolicy $user, TicketSystem $ticket_system)
    {
        if ($user->canDo('ticket_system.ticket_system.edit') && $user->isAdmin()) {
            return true;
        }

        return $ticket_system->user_id == user_id() && $ticket_system->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given ticket_system.
     *
     * @param UserPolicy $user
     * @param TicketSystem $ticket_system
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TicketSystem $ticket_system)
    {
        return $ticket_system->user_id == user_id() && $ticket_system->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given ticket_system.
     *
     * @param UserPolicy $user
     * @param TicketSystem $ticket_system
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TicketSystem $ticket_system)
    {
        if ($user->canDo('ticket_system.ticket_system.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ticket_system.
     *
     * @param UserPolicy $user
     * @param TicketSystem $ticket_system
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TicketSystem $ticket_system)
    {
        if ($user->canDo('ticket_system.ticket_system.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
