<?php

namespace Litecms\TicketSystem\Providers;

use Illuminate\Support\ServiceProvider;

class TicketSystemServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'ticket_system');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'ticket_system');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.ticket_system', function ($app) {
            return $this->app->make('Litecms\TicketSystem\TicketSystem');
        });

                // Bind TicketSystem to repository
        $this->app->bind(
            'Litecms\TicketSystem\Interfaces\TicketSystemRepositoryInterface',
            \Litecms\TicketSystem\Repositories\Eloquent\TicketSystemRepository::class
        );

        $this->app->register(\Litecms\TicketSystem\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\TicketSystem\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\TicketSystem\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.ticket_system'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/ticket_system.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/ticket_system')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/ticket_system')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
